<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Editando PodCast</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Colocado el:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Expira:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Mantener</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Estado del Post:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>E-Mail del autor:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>URL del artículo:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>URL comentarios:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Texto fuente:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>URL fuente:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>&amp;Reporte de
Episodios</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Fecha/Ho al aire:</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Enlace al medio:</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation>Expira el:</translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Enlace</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Podcast List</source>
        <translation>Lista de Podcasts</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Publicar de
Car&amp;t./Audio</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Publicar de
&amp;Archivo</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Subiendo Audio...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Longitud</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>&amp;Reporte de
Suscripción</translation>
    </message>
    <message>
        <source> </source>
        <translation></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Sólo Mostrar sin Expirar</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Sólo mostrar activos</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Error de Post</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Borrar Podcast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>¿Está seguro de borrar este Podcast?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Eliminando Podcast...</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Error remoto</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation>¡No fue posible eliminar audio remoto!
</translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation>El servidor dio el error: &quot;</translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation> ¿Continuar eliminando podcasts?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="obsolete">RDCastManager - Equipo </translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Usuario: [Desconocido]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">No puedo conectarme</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Nombre Clave</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Nombre del Feed</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Podcasts</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Ver Feed</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Elegir Fechas del Reporte</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>Fech. &amp;Inicio:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>Fech. &amp;Fin:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>&amp;Generar
Reporte</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
</TS>
